package cn.com.ty.lift.enterprise.oa.controller;

import cn.com.ty.lift.common.utils.Judge;
import cn.com.ty.lift.enterprise.common.CountPage;
import cn.com.ty.lift.enterprise.common.Values;
import cn.com.ty.lift.enterprise.oa.dto.LiftCertificateRequest;
import cn.com.ty.lift.enterprise.oa.dto.LiftCertificateResponse;
import cn.com.ty.lift.enterprise.oa.entity.LiftCertificate;
import cn.com.ty.lift.enterprise.oa.service.LiftCertificateService;
import cn.com.xwy.boot.web.dto.RestResponse;
import com.baomidou.mybatisplus.core.metadata.IPage;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;


/**
 * <p>
 * 操作证 前端控制器
 * </p>
 *
 * @author wcz
 * @since 2019-12-04
 */
@Slf4j
@AllArgsConstructor
@RestController
@RequestMapping("/oa/liftCertificate")
public class LiftCertificateController {

    private LiftCertificateService liftCertificateService;

    /**
     * 根据id查找
     * @param request
     * @return
     */
    @PostMapping("findOne")
    public RestResponse findOne(@RequestBody LiftCertificateRequest request) {
        Long id = request.getId();
        Judge.id(id);
        LiftCertificateResponse entity = liftCertificateService.findByIdWithInfo(request);
        return RestResponse.success(entity);
    }

    /**
     * 根据条件查询
     * @param request
     * @return
     */
    @PostMapping("list")
    public RestResponse list(@RequestBody LiftCertificateRequest request) {
        IPage<LiftCertificateResponse> pages = liftCertificateService.pageByCondition(request);
        Judge.notNull(pages);
        long count = liftCertificateService.countByCondition(request);
        CountPage<LiftCertificateResponse> countPage = new CountPage<>(count, pages);
        return RestResponse.success(countPage);
    }

    /**
     * 更新操作证信息
     * @param entity
     * @return
     */
    @PostMapping("modify")
    public RestResponse modify(@RequestBody LiftCertificate entity) {
        Long id = entity.getId();
        Long ownerId = entity.getOwnerId();
        Long mtCompanyId = entity.getMtCompanyId();
        Judge.id(id, ownerId, mtCompanyId);
        LiftCertificate certificate = liftCertificateService.findByUserAndMtCompany(id,ownerId,mtCompanyId);
        Judge.notNull(certificate,Values.Lc.CertNotExist);
        boolean result = liftCertificateService.updateById(entity);
        return RestResponse.success(result);
    }

    /**
     * 操作证审核
     * @param request
     * @return
     */
    @PostMapping("audit")
    public RestResponse audit(@RequestBody LiftCertificateRequest request) {
        Long id = request.getId();
        Judge.id(id);
        //0：无证，1：待审核，2：审核未通过，3：审核通过，4：超期
        LiftCertificate liftCertificate = liftCertificateService.getById(id);
        Judge.notNull(liftCertificate);
        Judge.isTrue(Values.Lc.toAudit(liftCertificate.getStatus()), Values.Lc.MustToAudit);
        int status = request.isPass() ? Values.Lc.Status_AuditPass : Values.Lc.Status_AuditFail;
        liftCertificate.setStatus(status);
        boolean result = liftCertificateService.saveOrUpdate(liftCertificate);
        return RestResponse.success(result);
    }

    /**
     * 新增操作证
     * @param entity
     * @return
     */
    @PostMapping("add")
    public RestResponse add(@Valid @RequestBody LiftCertificate entity) {
        Long ownerId = entity.getOwnerId();
        Long mtCompanyId = entity.getMtCompanyId();

        int count = liftCertificateService.countByUserAndMtCompany(ownerId, mtCompanyId);
        Judge.lt0(count, Values.Lc.CertHadExist);

        entity.setStatus(Values.Lc.Status_ToAudit);

        boolean result = liftCertificateService.saveOrUpdate(entity);
        return RestResponse.success(result);

    }
}
